.. toctree::
   :hidden:

   Installation <installation>
   usage
   concepts
   API Reference <modules>
   Help Us Improve <contributing>
   Code of Conduct <code-of-conduct>
   Developer Credits <authors>
   Software License <license>
   Project History <history>

.. include:: ../README.rst

